from django import template
from django.templatetags.static import static
from django.utils import formats
from django.utils.safestring import mark_safe

register = template.Library()


@register.filter
def value(val, pm=False, r=2):
    if val is None:
        return ""
    _prefix = ""
    _suffix = "&nbsp;€"
    _val = formats.number_format(val, decimal_pos=r, use_l10n=True, force_grouping=True)

    if val > 0:
        if pm:
            _prefix += "&plus;&nbsp;"
    elif val < 0:
        _val = _val[1:]
        _prefix += "&minus;&nbsp;"

    return mark_safe(f"{_prefix}{_val}{_suffix}")


@register.filter
def pmvalue(val):
    return value(val, True)


@register.filter
def pmrvalue(val):
    return value(val, True, r=0)


@register.filter
def remix(icon, cls=""):
    return mark_safe(f"""<span class="ri-{icon}-line {cls}"></span>""")


@register.filter
def extension(file):
    return file.name.split(".")[-1].upper()


@register.filter
def verbose_name(obj):
    return obj._meta.verbose_name


@register.filter
def adding(obj):
    return obj._state.adding


@register.simple_tag
def css(href):
    return mark_safe(
        f"""<link rel="stylesheet" href="{static(href)}" type="text/css">"""
    )
